@@ -3,6 +3,7 @@
 
   SPDX-FileCopyrightText: 2007-2014 Nick Shaforostoff <shafff@ukr.net>
   SPDX-FileCopyrightText: 2018-2019 Simon Depiets <sdepiets@gmail.com>
+  SPDX-FileCopyrightText: 2022 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
 
   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
@@ -330,6 +331,14 @@ ProjectModel* Project::model()
     return m_model;
 }
 
+QString Project::branchPotDir() const
+{
+    QDir poDir = Project::poDir();
+    QString potDirRelativelyToPoDir = poDir.relativeFilePath(Project::potDir());
+    QDir branchPotDir (Project::branchDir() + '/' + potDirRelativelyToPoDir);
+    return absolutePath(branchPotDir.absolutePath());
+}
+
 void Project::setDefaults()
 {
     ProjectBase::setDefaults();
